==> knowledge-center-api-0.1.10-sources.jar: cn/yoofans/knowledge/center/api/dto/read/ReadStageDTO.java <==
/**
 * Copyright (C), 2015-2018, XXX有限公司
 * FileName: ReadStageDTO
 * Author:   amu
 * Date:     2018/5/22 下午9:07
 * Description:
 * History:
 * <author>          <time>          <version>          <desc>
 * 作者姓名           修改时间           版本号              描述
 */
package cn.yoofans.knowledge.center.api.dto.read;

import java.io.Serializable;
import java.util.Date;

import org.apache.commons.lang3.builder.ToStringBuilder;

/**
 * 〈一句话功能简述〉<br>
 * 〈〉
 *
 * @author amu
 * @create 2018/5/22
 * @since 1.0.0
 */
public class ReadStageDTO implements Serializable {

    private static final long serialVersionUID = -3504269741391660144L;

    private Long id;

    private Long readId;

    private Date beginDate;

    private Integer stageNum;

    /**
     * 老师微信地址
     */
    private String teachers;
    // private String wxQrcodeUrl;

    private String commentPosterType;

    private Long lecturerId;

    private String readQrcode;//公众号二维码

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getReadId() {
        return readId;
    }

    public void setReadId(Long readId) {
        this.readId = readId;
    }

    public Date getBeginDate() {
        return beginDate;
    }

    public void setBeginDate(Date beginDate) {
        this.beginDate = beginDate;
    }

    public Integer getStageNum() {
        return stageNum;
    }

    public void setStageNum(Integer stageNum) {
        this.stageNum = stageNum;
    }

    public String getTeachers() {
        return teachers;
    }

    public void setTeachers(String teachers) {
        this.teachers = teachers;
    }

    public String getCommentPosterType() {
        return commentPosterType;
    }

    public void setCommentPosterType(String commentPosterType) {
        this.commentPosterType = commentPosterType;
    }

    public Long getLecturerId() {
        return lecturerId;
    }

    public void setLecturerId(Long lecturerId) {
        this.lecturerId = lecturerId;
    }

    public String getReadQrcode() {
        return readQrcode;
    }

    public void setReadQrcode(String readQrcode) {
        this.readQrcode = readQrcode;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }
}

==> knowledge-center-api-0.3.8-sources.jar: cn/yoofans/knowledge/center/api/dto/read/ReadStageDTO.java <==
/**
 * Copyright (C), 2015-2018, XXX有限公司
 * FileName: ReadStageDTO
 * Author:   amu
 * Date:     2018/5/22 下午9:07
 * Description:
 * History:
 * <author>          <time>          <version>          <desc>
 * 作者姓名           修改时间           版本号              描述
 */
package cn.yoofans.knowledge.center.api.dto.read;

import java.io.Serializable;
import java.util.Date;

import org.apache.commons.lang3.builder.ToStringBuilder;

/**
 * 〈一句话功能简述〉<br>
 * 〈〉
 *
 * @author amu
 * @create 2018/5/22
 * @since 1.0.0
 */
public class ReadStageDTO implements Serializable {

    private static final long serialVersionUID = -3504269741391660144L;

    private Long id;

    private Long readId;

    private Date beginDate;

    private Integer stageNum;

    /**
     * 老师微信地址
     */
    private String teachers;
    // private String wxQrcodeUrl;

    private String commentPosterType;

    private Long lecturerId;

    private String readQrcode;//公众号二维码

    private Long readQrcodeDcd;// 二维码dcd（推广位）

    private Long channelId;  //渠道id

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getReadId() {
        return readId;
    }

    public void setReadId(Long readId) {
        this.readId = readId;
    }

    public Date getBeginDate() {
        return beginDate;
    }

    public void setBeginDate(Date beginDate) {
        this.beginDate = beginDate;
    }

    public Integer getStageNum() {
        return stageNum;
    }

    public void setStageNum(Integer stageNum) {
        this.stageNum = stageNum;
    }

    public String getTeachers() {
        return teachers;
    }

    public void setTeachers(String teachers) {
        this.teachers = teachers;
    }

    public String getCommentPosterType() {
        return commentPosterType;
    }

    public void setCommentPosterType(String commentPosterType) {
        this.commentPosterType = commentPosterType;
    }

    public Long getLecturerId() {
        return lecturerId;
    }

    public void setLecturerId(Long lecturerId) {
        this.lecturerId = lecturerId;
    }

    public String getReadQrcode() {
        return readQrcode;
    }

    public void setReadQrcode(String readQrcode) {
        this.readQrcode = readQrcode;
    }

    public Long getReadQrcodeDcd() {
        return readQrcodeDcd;
    }

    public void setReadQrcodeDcd(Long readQrcodeDcd) {
        this.readQrcodeDcd = readQrcodeDcd;
    }

    public Long getChannelId() {
        return channelId;
    }

    public void setChannelId(Long channelId) {
        this.channelId = channelId;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }
}
